About
=====

This package provides a python wrapper to the Montage Astronomical Image Mosaic
Engine, including both functions to access individual Montage commands, and
high-level functions to facilitate mosaicking and re-projecting.
